summaryrefslogtreecommitdiff
path: root/build.sh
diff options
context:
space:
mode:
authorMatt Ellis <matell@microsoft.com>2015-04-15 00:44:22 -0700
committerMatt Ellis <matell@microsoft.com>2015-04-15 00:44:22 -0700
commit44e3523980aa1b36727d219b246712f804722124 (patch)
tree9dbfe8f546afaeb2a6532c942478994b5a6105bb /build.sh
parent7a94cd137e6f737b1663706fd98c4c6b22cd2667 (diff)
downloadcoreclr-44e3523980aa1b36727d219b246712f804722124.tar.gz
coreclr-44e3523980aa1b36727d219b246712f804722124.tar.bz2
coreclr-44e3523980aa1b36727d219b246712f804722124.zip
Use "x64" and not "amd64" in build.sh
The help text for build.sh said that you should pass "x64" as a paramter for the build architecture. However, the script was looking for amd64. Update the script to look for x64 since that's what we use everywhere else (and the behavior you got if you didn't pass an argument to this script.) Fixes #689
Diffstat (limited to 'build.sh')
-rwxr-xr-xbuild.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/build.sh b/build.sh
index b6e885e1fe..0320cc7400 100755
--- a/build.sh
+++ b/build.sh
@@ -84,7 +84,7 @@ echo "Commencing CoreCLR Repo build"
# Argument types supported by this script:
#
# Build architecture - valid value is: Amd64.
# Build Type - valid values are: Debug, Release
#
# Set the default arguments for build
@@ -138,7 +138,7 @@ for i in "$@"
usage
exit 1
;;
- amd64)
+ x64)
__BuildArch=x64
__MSBuildBuildArch=x64
;;
@@ -84,7 +84,7 @@ echo "Commencing CoreCLR Repo build"
# Argument types supported by this script:
#
-# Build architecture - valid value is: Amd64.
+# Build architecture - valid value is: x64.
# Build Type - valid values are: Debug, Release
#